@@ -8,10 +8,10 @@
 
 #include "MarbleDebug.h"
 
+#include "GeoDataMultiGeometry.h"
+#include "GeoDataPlacemark.h"
 #include "KmlElementDictionary.h"
 #include "KmlObjectTagHandler.h"
-#include "GeoDataPlacemark.h"
-#include "GeoDataMultiGeometry.h"
 
 #include "GeoParser.h"
 
@@ -19,22 +19,22 @@ namespace Marble
 {
 namespace kml
 {
-KML_DEFINE_TAG_HANDLER( MultiGeometry )
+KML_DEFINE_TAG_HANDLER(MultiGeometry)
 
-GeoNode* KmlMultiGeometryTagHandler::parse( GeoParser& parser ) const
+GeoNode *KmlMultiGeometryTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_MultiGeometry)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_MultiGeometry)));
 
     GeoStackItem parentItem = parser.parentElement();
 
-    GeoDataMultiGeometry *geom = new GeoDataMultiGeometry;
-    KmlObjectTagHandler::parseIdentifiers( parser, geom );
-    if( parentItem.represents( kmlTag_Placemark ) ) {
-        parentItem.nodeAs<GeoDataPlacemark>()->setGeometry( geom );
+    auto geom = new GeoDataMultiGeometry;
+    KmlObjectTagHandler::parseIdentifiers(parser, geom);
+    if (parentItem.represents(kmlTag_Placemark)) {
+        parentItem.nodeAs<GeoDataPlacemark>()->setGeometry(geom);
         return parentItem.nodeAs<GeoDataPlacemark>()->geometry();
 
-    } else if( parentItem.represents( kmlTag_MultiGeometry ) ) {
-        parentItem.nodeAs<GeoDataMultiGeometry>()->append( geom );
+    } else if (parentItem.represents(kmlTag_MultiGeometry)) {
+        parentItem.nodeAs<GeoDataMultiGeometry>()->append(geom);
         return geom;
     } else {
         delete geom;
