@@ -7,31 +7,30 @@
 
 #include "MarbleDebug.h"
 
-#include "KmlElementDictionary.h"
-#include "GeoDataScreenOverlay.h"
 #include "GeoDataParser.h"
+#include "GeoDataScreenOverlay.h"
+#include "KmlElementDictionary.h"
 #include "MarbleGlobal.h"
 
 namespace Marble
 {
 namespace kml
 {
-KML_DEFINE_TAG_HANDLER( overlayXY )
+KML_DEFINE_TAG_HANDLER(overlayXY)
 
-GeoNode* KmloverlayXYTagHandler::parse( GeoParser& parser ) const
+GeoNode *KmloverlayXYTagHandler::parse(GeoParser &parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_overlayXY)));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1StringView(kmlTag_overlayXY)));
 
     GeoStackItem parentItem = parser.parentElement();
 
-    if (parentItem.represents( kmlTag_ScreenOverlay ))
-    {
+    if (parentItem.represents(kmlTag_ScreenOverlay)) {
         GeoDataVec2 vec2(parser.attribute("x").trimmed().toFloat(),
                          parser.attribute("y").trimmed().toFloat(),
                          parser.attribute("xunits").trimmed(),
                          parser.attribute("yunits").trimmed());
 
-        parentItem.nodeAs<GeoDataScreenOverlay>()->setOverlayXY( vec2 );
+        parentItem.nodeAs<GeoDataScreenOverlay>()->setOverlayXY(vec2);
     }
     return nullptr;
 }
